package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.entity.MusicSceneRelate;
import com.ruoyi.system.mapper.MusicSceneRelateMapper;
import com.ruoyi.system.service.IMusicSceneRelateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Service
public class MusicSceneRelateServiceImpl implements IMusicSceneRelateService 
{
    @Autowired
    private MusicSceneRelateMapper musicSceneRelateMapper;


    @Override
    public MusicSceneRelate selectMusicSceneRelateById(String id) {
        return null;
    }

    @Override
    public List<MusicSceneRelate> selectMusicSceneRelateList(MusicSceneRelate musicSceneRelate) {
        return null;
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param musicSceneRelate 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertMusicSceneRelate(MusicSceneRelate musicSceneRelate)
    {
        return musicSceneRelateMapper.insertMusicSceneRelate(musicSceneRelate);
    }

    @Override
    public int updateMusicSceneRelate(MusicSceneRelate musicSceneRelate) {
        return 0;
    }

    @Override
    public int deleteMusicSceneRelateByIds(String[] ids) {
        return 0;
    }

    @Override
    public int deleteMusicSceneRelateById(String id) {
        return 0;
    }

}
