package com.ruoyi.web.controller.back;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.MusicSceneRelate;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.service.IMusicSceneRelateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@RestController
@RequestMapping("/back/relate")
public class MusicSceneRelateController extends BaseController
{
    @Autowired
    private IMusicSceneRelateService musicSceneRelateService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:relate:list')")
    @GetMapping("/list")
    public TableDataInfo list(MusicSceneRelate musicSceneRelate)
    {
        startPage();
        List<MusicSceneRelate> list = musicSceneRelateService.selectMusicSceneRelateList(musicSceneRelate);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:relate:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MusicSceneRelate musicSceneRelate)
    {
        List<MusicSceneRelate> list = musicSceneRelateService.selectMusicSceneRelateList(musicSceneRelate);
        ExcelUtil<MusicSceneRelate> util = new ExcelUtil<MusicSceneRelate>(MusicSceneRelate.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:relate:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(musicSceneRelateService.selectMusicSceneRelateById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:relate:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MusicSceneRelate musicSceneRelate)
    {
        return toAjax(musicSceneRelateService.insertMusicSceneRelate(musicSceneRelate));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:relate:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MusicSceneRelate musicSceneRelate)
    {
        return toAjax(musicSceneRelateService.updateMusicSceneRelate(musicSceneRelate));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:relate:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(musicSceneRelateService.deleteMusicSceneRelateByIds(ids));
    }
}
